@@ -180,5 +180,5 @@ def update_versioned_files(
             ) from rollback_exc
 
         raise UpgradeException(
-            "An exception occured while upgrading; rollback successful."
+            f"An exception occured while upgrading; rollback successful.\n\nException: {repr(upgrade_exc)}"
         ) from upgrade_exc
