@@ -1,6 +1,7 @@
-from importlib import resources
 from pathlib import Path
 
+CHANGELOGGER_VERSION = "0.12.0"
+
 DEFAULT_CHANGELOG_PATH = Path("CHANGELOG.md")
 
 DEFAULT_OVERVIEW_JINJA_PATTERN = (
@@ -8,12 +9,11 @@ DEFAULT_OVERVIEW_JINJA_PATTERN = (
 )
 DEFAULT_LINKS_JINJA_PATTERN = r"\[Unreleased\]:.*\n"
 
-DEFAULT_OVERVIEW_JINJA_PATH = resources.files("changelogger").joinpath(
-    "assets/.cl.overview.jinja2"
-)
-DEFAULT_LINKS_JINJA_PATH = resources.files("changelogger").joinpath(
-    "assets/.cl.links.jinja2"
-)
+DEFAULT_RELEASE_NOTES_TEMPLATE = Path("release_notes.md.jinja2")
+DEFAULT_OVERVIEW_TEMPLATE = Path("overview.jinja2")
+DEFAULT_LINKS_TEMPLATE = Path("links.jinja2")
+
+DEFAULT_TEMPLATES_DIR = Path(".changelogger/templates/")
 
 CHANGELOGGER_NAME = ".changelogger.yml"
 
@@ -26,5 +26,3 @@ CHANGELOGGER_PATH = (
     and p3
     or p1
 )
-
-CHANGELOGGER_VERSION = "0.11.3"
