@@ -1,6 +1,8 @@
 from importlib import resources
 
-from changelogger.conf.defaults import *
+from jinja2 import Environment, FileSystemLoader
+
+from changelogger.conf.defaults import *  # nopycln: import
 from changelogger.conf.models import ChangeloggerConfig
 
 _config = ChangeloggerConfig.from_config_or_default()
@@ -10,20 +12,38 @@ DEBUG = False
 CHANGELOG_PATH = _config.changelog.rel_path
 
 CHANGELOG_JINJA = resources.files("changelogger").joinpath(
-    "assets/changelog.jinja2",
+    "templates/changelog.md.jinja2",
 )
 
+TEMPLATES_DIR = _config.templates_dir
+
 OVERVIEW_JINJA_PATTERN = _config.changelog.overview.pattern
-OVERVIEW_JINJA_PATH = _config.changelog.overview.jinja_rel_path
+OVERVIEW_TEMPLATE = _config.changelog.overview.template
 
 LINKS_JINJA_PATTERN = _config.changelog.links.pattern
-LINKS_JINJA_PATH = _config.changelog.links.jinja_rel_path
+LINKS_TEMPLATE = _config.changelog.links.template
+
+RELEASE_NOTES_TEMPLATE = _config.changelog.release_notes.template
 
 VERSIONED_FILES = _config.versioned_files
 VERSIONED_FILES.extend(_config.changelog.as_versioned_files())
 
 HAS_DEFAULTS = _config.changelog.has_defaults()
 
+
+with resources.as_file(
+    resources.files("changelogger").joinpath("templates"),
+) as package_templates:
+    TMPL_ENV = Environment(
+        loader=FileSystemLoader(
+            [
+                TEMPLATES_DIR,
+                package_templates,
+            ]
+        )
+    )
+
+
 # THIS MUST BE IMPORTED LAST
 try:
     from changelogger.conf._settings_override import *  # nopycln: import
